# User Profile

*This file is automatically updated from conversations. Manual edits are also welcome.*

## Basic Info
- Name:
- Role:
- Timezone:

## Expertise
[Observed from conversations]

## Communication Preferences
[Observed from conversations]

## Decision Patterns
[Observed from conversations]
